/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.linkis.manager.common.constant;

public class RMConstant {

  public static final String CPU = "CPU";

  public static final String MEMORY = "Memory";

  public static final String APP_INSTANCE = "Instance";

  public static final String CPU_UNIT = "cores";

  public static final String KUBERNETES_CPU_UNIT = "milli cores";
  public static final String KUBERNETES_NAMESPACE = "namespace";
  public static final String KUBERNETES_NAMESPACE_UNIT = "";
  public static final String MEMORY_UNIT_BYTE = "bytes";

  public static final String INSTANCE_UNIT = "";
}
